/*******************************************************************************
*  skPCF8563.h - PCF8563(RTC)用関数ライブラリのヘッダファイル                  *
*                                                                              *
* ============================================================================ *
*   VERSION  DATE        BY             CHANGE/COMMENT                         *
* ---------------------------------------------------------------------------- *
*   1.00     2021-01-26  きむ茶工房     Create                                 *
* ============================================================================ *
*   Arduino IDE 1.8.12 (Ardino Duemilanove 328/UNO/Seeeduino XIAO)             *
*******************************************************************************/
#ifndef SKPCF8563_H
#define SKPCF8563_H

#include <Arduino.h>
#include <Wire.h>

#define PCF8563_address       0x51 // PCF8563のI2Cアドレス
#define PCF8563_CTL_STS2      0x01 // 制御/情報２レジスタアドレス
#define PCF8563_Weekdays      0x06 // 曜日をセットするレジスタアドレス
#define PCF8563_AlarmWeekday  0x0C // アラームの曜日をセットするレジスタアドレス
#define PCF8563_AlarmDay      0x0B // アラームの日をセットするレジスタアドレス
#define PCF8563_AlarmHour     0x0A // アラームの時をセットするレジスタアドレス
#define PCF8563_AlarmMinute   0x09 // アラームの分をセットするレジスタアドレス
#define PCF8563_AIE           0x02 // アラームの有効・無効フラグのビット位置
#define PCF8563_AF            0x08 // アラームフラグのビット位置
#define PCF8563_Timer_CTL     0x0E // タイマーの制御レジスタアドレス
#define PCF8563_TimerValue    0x0F // タイマーのカウントダウン値レジスタアドレス
#define PCF8563_TIE           0x01 // アラームの有効・無効フラグのビット位置
#define PCF8563_TF            0x04 // アラームフラグのビット位置
// タイマーソースのクロック周波数値
#define PCF8563_TimerF_1_60Hz 0x03 // タイマー使わない時は消費電力の為にこのモードにする事
#define PCF8563_TimerF_1Hz    0x02
#define PCF8563_TimerF_64Hz   0x01
#define PCF8563_TimerF_4096Hz 0x00

class skPCF8563 {
  public:
         skPCF8563(void) ;
    void SetWeekdays(uint8_t wdays) ;
    void SetAlarmWeekday(uint8_t wday) ;
    void SetAlarmDay(uint8_t day) ;
    void SetAlarmHour(uint8_t hour) ;
    void SetAlarmMinute(uint8_t minute) ;
    void SetAlarmTime(uint8_t minute,uint8_t hour,uint8_t day,uint8_t wday) ;
    uint8_t AlarmMatch() ;
    void AlarmEnable() ;
    void AlarmDisable() ;
    void AlarmClearFlag() ;
    void TimerCountdownStart(uint8_t timer,uint8_t frequency) ;
    uint8_t TimerCountdownCheck() ;
    void TimerDisable() ;
    void TimerClearFlag() ;
    void write(uint8_t address, uint8_t data) ;
    uint8_t read(uint8_t address) ;
  private:
    
};
#endif
